<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE" sourcelanguage="en_US">
<context>
    <name>(GameTypes)</name>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="23"/>
        <source>OTHER</source>
        <translation>ANNAN</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="24"/>
        <source>AMIGA</source>
        <translation>AMIGA</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="25"/>
        <source>ATARI</source>
        <translation>ATARI</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="26"/>
        <source>GAMEGEAR</source>
        <translation>GAMEGEAR</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="27"/>
        <source>GENESIS/MEGADRIVE</source>
        <translation>GENESIS/MEGADRIVE</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="28"/>
        <source>MAME</source>
        <translation>MAME</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="29"/>
        <source>N64</source>
        <translation>N64</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="30"/>
        <source>NES</source>
        <translation>NES</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="31"/>
        <source>PC GAME</source>
        <translation>PC-SPEL</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="32"/>
        <source>PCE/TG16</source>
        <translation>PCE/TG16</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="33"/>
        <source>SEGA/MASTER SYSTEM</source>
        <translation>SEGA/MASTER SYSTEM</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="34"/>
        <source>SNES</source>
        <translation>SNES</translation>
    </message>
</context>
<context>
    <name>GameGeneralSettings</name>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="175"/>
        <source>MythGame Settings -- General</source>
        <translation type="unfinished">Inställningar för MythGame - Allmänt</translation>
    </message>
</context>
<context>
    <name>GameHandler</name>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="159"/>
        <location filename="../mythgame/gamehandler.cpp" line="432"/>
        <source>19xx</source>
        <comment>Default game year</comment>
        <translation>19xx</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="160"/>
        <location filename="../mythgame/gamehandler.cpp" line="430"/>
        <source>Unknown</source>
        <comment>Unknown country</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="161"/>
        <location filename="../mythgame/gamehandler.cpp" line="433"/>
        <location filename="../mythgame/gamehandler.cpp" line="441"/>
        <source>Unknown</source>
        <comment>Unknown game name</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="162"/>
        <location filename="../mythgame/gamehandler.cpp" line="190"/>
        <source>Unknown</source>
        <comment>Unknown genre</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="163"/>
        <location filename="../mythgame/gamehandler.cpp" line="434"/>
        <source>Unknown</source>
        <comment>Unknown plot</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="164"/>
        <location filename="../mythgame/gamehandler.cpp" line="435"/>
        <source>Unknown</source>
        <comment>Unknown publisher</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="165"/>
        <location filename="../mythgame/gamehandler.cpp" line="436"/>
        <source>0</source>
        <comment>Default game version</comment>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="191"/>
        <location filename="../mythgame/gamehandler.cpp" line="429"/>
        <source>Unknown %1</source>
        <comment>Unknown genre</comment>
        <extracomment>%1 is the game type, when we don&apos;t know the genre we use the * game type</extracomment>
        <translation>Okänd %1</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="232"/>
        <source>%1 appears to be missing.
Remove it from the database?</source>
        <extracomment>%1 is the file name</extracomment>
        <translation>%1 verkar saknas.
Ta bort det från databasen?</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="240"/>
        <location filename="../mythgame/gamehandler.cpp" line="617"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="241"/>
        <source>No to all</source>
        <translation>Nej till alla</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="242"/>
        <location filename="../mythgame/gamehandler.cpp" line="618"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="243"/>
        <source>Yes to all</source>
        <translation>Ja till alla</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="391"/>
        <source>Updating %1 (%2) ROM database</source>
        <extracomment>%1 is the system name, %2 is the game type</extracomment>
        <translation>Uppdaterar %1 (%2) ROM-databas</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="527"/>
        <source>Verifying %1 files...</source>
        <extracomment>%1 is the system name</extracomment>
        <translation>Verifierar %1-filer...</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="611"/>
        <source>This will clear all game metadata from the database. Are you sure you want to do this?</source>
        <translation>Detta rensar all spelmetadata från databasen. Är du säker på att du vill göra det?</translation>
    </message>
    <message>
        <location filename="../mythgame/gamehandler.cpp" line="703"/>
        <location filename="../mythgame/gamehandler.cpp" line="731"/>
        <source>Scanning for %1 games...</source>
        <extracomment>%1 is the system name</extracomment>
        <translation>Söker efter %1-spel...</translation>
    </message>
</context>
<context>
    <name>GamePlayersList</name>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="353"/>
        <source>Game Players</source>
        <translation type="unfinished">Spelare</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="360"/>
        <source>(New Game Player)</source>
        <translation type="unfinished">(Ny spelare)</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="366"/>
        <source>%1 (%2)</source>
        <comment>Game player/emulator display</comment>
        <extracomment>%1 is the player/emulator name, %2 is the type of player/emulator</extracomment>
        <translation type="unfinished">%1 (%2)</translation>
    </message>
    <message>
        <location filename="../mythgame/gamesettings.cpp" line="398"/>
        <source>Player Name</source>
        <translation type="unfinished">Spelarnamn</translation>
    </message>
</context>
<context>
    <name>GameScanner</name>
    <message>
        <location filename="../mythgame/gamescan.cpp" line="70"/>
        <source>Verifying game files...</source>
        <translation>Verifierar spelfiler...</translation>
    </message>
    <message>
        <location filename="../mythgame/gamescan.cpp" line="110"/>
        <source>Updating game database...</source>
        <translation>Uppdaterar speldatabasen...</translation>
    </message>
    <message>
        <location filename="../mythgame/gamescan.cpp" line="143"/>
        <source>Searching for games...</source>
        <translation>Söker efter spel...</translation>
    </message>
</context>
<context>
    <name>GameUI</name>
    <message>
        <location filename="../mythgame/gameui.cpp" line="153"/>
        <source>All Games</source>
        <translation>Alla spel</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="158"/>
        <source>-   By Genre</source>
        <translation>-   Enligt genre</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="163"/>
        <source>-   By Year</source>
        <translation>-   Enligt år</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="168"/>
        <source>-   By Name</source>
        <translation>-   Enligt namn</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="173"/>
        <source>-   By Publisher</source>
        <translation>-   Enligt utgivare</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="269"/>
        <source>Choose System for:
%1</source>
        <extracomment>%1 is the game name</extracomment>
        <translation>Välj system för:
%1</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="544"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="439"/>
        <location filename="../mythgame/gameui.cpp" line="524"/>
        <source>Scan For Changes</source>
        <translation>Sök efter ändringar</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="445"/>
        <location filename="../mythgame/gameui.cpp" line="528"/>
        <source>Show Information</source>
        <translation>Visa information</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="447"/>
        <location filename="../mythgame/gameui.cpp" line="533"/>
        <source>Remove Favorite</source>
        <translation>Ta bort favorit</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="449"/>
        <location filename="../mythgame/gameui.cpp" line="532"/>
        <source>Make Favorite</source>
        <translation>Skapa favorit</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="450"/>
        <location filename="../mythgame/gameui.cpp" line="537"/>
        <source>Retrieve Details</source>
        <translation>Hämta detaljer</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="451"/>
        <location filename="../mythgame/gameui.cpp" line="520"/>
        <source>Edit Details</source>
        <translation>Redigera detaljer</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="645"/>
        <source>Failed to retrieve image(s)</source>
        <translation>Misslyckades att hämta bild(er)</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="647"/>
        <source>Check logs</source>
        <translation>Kontrollera loggar</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="941"/>
        <source>Fetching details for %1</source>
        <extracomment>%1 is the game name</extracomment>
        <translation>Hämtar detaljer för %1</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="481"/>
        <source>Game Search</source>
        <translation>Spelsökning</translation>
    </message>
    <message>
        <location filename="../mythgame/gameui.cpp" line="139"/>
        <source>Favorites</source>
        <translation>Favoriter</translation>
    </message>
</context>
<context>
    <name>MythControls</name>
    <message>
        <location filename="../mythgame/mythgame.cpp" line="113"/>
        <source>Game frontend</source>
        <translation>Spelgränssnitt</translation>
    </message>
    <message>
        <location filename="../mythgame/mythgame.cpp" line="116"/>
        <source>Toggle the current game as a favorite</source>
        <translation>Växla aktuellt spel som favorit</translation>
    </message>
    <message>
        <location filename="../mythgame/mythgame.cpp" line="118"/>
        <source>Show incremental search dialog</source>
        <translation>Visa inkrementell sökdialog</translation>
    </message>
    <message>
        <location filename="../mythgame/mythgame.cpp" line="120"/>
        <source>Incremental search find next match</source>
        <translation>Nästa träff vid inkrementell sökning</translation>
    </message>
    <message>
        <location filename="../mythgame/mythgame.cpp" line="122"/>
        <source>Download metadata for current item</source>
        <translation>Hämta metadata för aktuell post</translation>
    </message>
</context>
<context>
    <name>MythGameGeneralSettings</name>
    <message>
        <source>Game display order</source>
        <translation type="vanished">Visningsordning för spel</translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="vanished">Sorteringsordning för spelen - detta gäller alla system. Tillgängliga val: system, år, genre och spelnamn</translation>
    </message>
    <message>
        <source>Favorite display order</source>
        <translation type="vanished">Sorteringsordning för favoriter</translation>
    </message>
    <message>
        <source>Order in which to sort the games marked as favorites - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="vanished">Sorteringsordning för spel markerade som favoriter: detta gäller alla system. Tillgängliga val: system, år, genre och spelnamn</translation>
    </message>
    <message>
        <source>Indepth Game Scan</source>
        <translation type="vanished">Djupsökning av spel</translation>
    </message>
    <message>
        <source>Enabling this causes a game scan to gather CRC values and attempt to find out more detailed information about the game: NOTE this can greatly increase the time a game scan takes based on the amount of games scanned.</source>
        <translation type="vanished">Aktiveras detta gör det att CRC-värden samlas in vid en sökning av spel och mer detaljerad information om spelen försöker hittas: Observera: Detta kan väsentligt öka tidsåtgången för en sökning, beroende på antal spel.</translation>
    </message>
    <message>
        <source>Prompt for removal of deleted ROM(s)</source>
        <translation type="vanished">Bekräfta borttagning av raderad(e) ROM</translation>
    </message>
    <message>
        <source>This enables a prompt for removing deleted ROMs from the database during a game scan</source>
        <translation type="vanished">Detta aktiverar en fråga innan borttagna ROM raderas från databasen när en sökning av spel genomförs</translation>
    </message>
    <message>
        <source>Display Files Names in Game Tree</source>
        <translation type="vanished">Visa filnamn i spelträdet</translation>
    </message>
    <message>
        <source>Enabling this causes the filenames to be displayed in the game tree rather than the trimmed/looked up game name</source>
        <translation type="vanished">Aktiveras detta visas filnamnen i spelträdet i stället för förkortade/uppslagna spelnamn</translation>
    </message>
    <message>
        <source>Hash filenames in display</source>
        <translation type="vanished">Skapa kondensat för filnamn som visas</translation>
    </message>
    <message>
        <source>Enable hashing of names in the display tree. This can make navigating long lists a little faster</source>
        <translation type="vanished">Aktiverar kondensat för filnamn i visningsträdet. Det kan snabba upp navigering i långa listor något</translation>
    </message>
    <message>
        <source>Directory where Game Screenshots are stored</source>
        <translation type="vanished">Katalog där spelskärmbilder lagras</translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning screenshots.</source>
        <translation type="vanished">Denna katalog är standardplatsen att gå till när skärmbilder tilldelas.</translation>
    </message>
    <message>
        <source>Directory where Game Fanart is stored</source>
        <translation type="vanished">Kataloger där användarbilder för spel lagras</translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning fanart.</source>
        <translation type="vanished">Denna katalog är standardplatsen att gå till när användarbilder tilldelas.</translation>
    </message>
    <message>
        <source>Directory where Game Boxart is stored</source>
        <translation type="vanished">Katalog där förpackningsbilder för spel lagras</translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning boxart.</source>
        <translation type="vanished">Denna katalog är standardplatsen att gå till när förpackningsbilder tilldelas.</translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation type="vanished">Inställningar för MythGame - Allmänt</translation>
    </message>
</context>
<context>
    <name>MythGamePlayerEditor</name>
    <message>
        <source>Game Player Menu</source>
        <translation type="vanished">Spelarmeny</translation>
    </message>
    <message>
        <source>(New Game Player)</source>
        <translation type="vanished">(Ny spelare)</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="vanished">Redigera...</translation>
    </message>
    <message>
        <source>Delete...</source>
        <translation type="vanished">Ta bort...</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation type="vanished">Är du säker på att du vill ta bort denna post?</translation>
    </message>
    <message>
        <source>Yes, delete It</source>
        <translation type="vanished">Ja, ta bort den</translation>
    </message>
    <message>
        <source>No, don&apos;t</source>
        <translation type="vanished">Nej, avbryt</translation>
    </message>
    <message>
        <source>Game Players</source>
        <translation type="vanished">Spelare</translation>
    </message>
</context>
<context>
    <name>MythGamePlayerSettings</name>
    <message>
        <source>Allow games to span multiple ROMs/disks</source>
        <translation type="vanished">Tillåt spel att sträcka sig över flera ROM eller skivor</translation>
    </message>
    <message>
        <source>This setting means that we will look for items like game.1.rom, game.2.rom and consider them a single game.</source>
        <translation type="vanished">Inställningen betyder att sökningen letar efter spel som game.1.rom, game.2.rom och räknar dem som ett spel.</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="vanished">Kommando</translation>
    </message>
    <message>
        <source>Binary and optional parameters. Multiple commands separated with &apos;;&apos; . Use %s for the ROM name. %d1, %d2, %d3 and %d4 represent disks in a multidisk/game. %s auto appended if not specified</source>
        <translation type="vanished">Program och valfria parametrar. Flera kommandon separeras med &apos;;&apos;. Använd %s för ROM-namnet. %d1, %d2, %d3 och %d4 representerar skivor i spel med flera skivor. %s läggs till automatiskt om det inte anges</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Game type</extracomment>
        <translation type="vanished">Typ</translation>
    </message>
    <message>
        <source>Type of Game/Emulator. Mostly for informational purposes and has little effect on the function of your system.</source>
        <translation type="vanished">Typ av spel/emulator. Mest till för information och har föga effekt på systemets funktion.</translation>
    </message>
    <message>
        <source>ROM Path</source>
        <translation type="vanished">ROM-sökväg</translation>
    </message>
    <message>
        <source>Location of the ROM files for this emulator</source>
        <translation type="vanished">Plats för ROM-filerna för denna emulator</translation>
    </message>
    <message>
        <source>Working Directory</source>
        <translation type="vanished">Arbetskatalog</translation>
    </message>
    <message>
        <source>Directory to change to before launching emulator. Blank is usually fine</source>
        <translation type="vanished">Katalog att byta till innan emulatorn startas. Tomt är oftast ok</translation>
    </message>
    <message>
        <source>File Extensions</source>
        <translation type="vanished">Filändelser</translation>
    </message>
    <message>
        <source>A comma separated list of all file extensions for this emulator. Blank means any file under ROM PATH is considered to be used with this emulator</source>
        <translation type="vanished">En kommaseparerad lista över alla filändelser som används av denna emulator. Tomt betyder att alla filer under ROM-sökvägen anses användas av denna emulator</translation>
    </message>
    <message>
        <source>Game Player Setup</source>
        <translation type="vanished">Spelarinställningar</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <comment>Game player/emulator display</comment>
        <extracomment>%1 is the player/emulator name, %2 is the type of player/emulator</extracomment>
        <translation type="vanished">%1 (%2)</translation>
    </message>
    <message>
        <source>Player Name</source>
        <translation type="vanished">Spelarnamn</translation>
    </message>
    <message>
        <source>Name of this Game and or Emulator</source>
        <translation type="vanished">Namn på detta spel och/eller emulator</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <location filename="themestrings.h" line="103"/>
        <source>System:</source>
        <translation>System:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="109"/>
        <source>Year:</source>
        <translation>År:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="68"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="49"/>
        <source>Favorite:</source>
        <translation>Favorit:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="42"/>
        <source>Edit Game Information</source>
        <translation>Redigera spelinformation</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="56"/>
        <source>Game Name:</source>
        <translation>Spelnamn:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="32"/>
        <source>Country:</source>
        <translation>Land:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="83"/>
        <source>Publisher:</source>
        <translation>Utgivare:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="81"/>
        <source>Plot:</source>
        <translation>Handling:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="93"/>
        <source>Screenshot:</source>
        <translation>Skärmbild:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="47"/>
        <source>Fanart:</source>
        <translation>Användarbild:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="18"/>
        <source>Boxart:</source>
        <translation>Förpackningsbilder:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="12"/>
        <source>/path/to/the/thing.jpg</source>
        <translation>/sökväg/till/bilden.jpg</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="45"/>
        <source>Emulator:</source>
        <translation>Emulator:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="88"/>
        <source>Released %1</source>
        <translation>Utgivet %1</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="6"/>
        <source>%DATE%, %TIME%</source>
        <translation>%DATE%, %TIME%</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="5"/>
        <source>%00x00| - %%&quot;|SUBTITLE|&quot;
%%|YEARSTARS| - %%DESCRIPTION%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="7"/>
        <source>%Published by |publisher|%%, |YEAR%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="8"/>
        <source>%&quot;|SUBTITLE|&quot;

%%DESCRIPTION%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="9"/>
        <source>%cast%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="10"/>
        <source>%playcount% times</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="11"/>
        <source>%romname%%, |(rompath)%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="13"/>
        <source>Add game to Favorites:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="14"/>
        <source>Add games to your</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="16"/>
        <source>Add to favorites:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="19"/>
        <source>CRC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="21"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="23"/>
        <source>Clear data of all your games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="24"/>
        <source>Clear your game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="29"/>
        <source>Configure game emulators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="30"/>
        <source>Configure your game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="31"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="34"/>
        <source>Coverart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="35"/>
        <source>Coverart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="36"/>
        <source>Customize meta data of your games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="37"/>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="39"/>
        <source>Description: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="40"/>
        <source>Detailed information about your game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="43"/>
        <source>Edit Metadata</source>
        <translation>Redigera detaljer</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="46"/>
        <source>Fanart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="50"/>
        <source>File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="51"/>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="54"/>
        <source>GAMES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="58"/>
        <source>Game Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="59"/>
        <source>Game details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="60"/>
        <source>Game folders and general</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="62"/>
        <source>Game folders and general settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="64"/>
        <source>Game plot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="70"/>
        <source>Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="71"/>
        <source>Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="72"/>
        <source>Modify your game&apos;s metadata.</source>
        <translation>Redigera ditt spels detaljer.</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="73"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="74"/>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="77"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="80"/>
        <source>Players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="82"/>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="85"/>
        <source>ROM path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="87"/>
        <source>ROM:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="89"/>
        <source>Rompath:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="90"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="92"/>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="94"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="95"/>
        <source>Search Boxart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="96"/>
        <source>Search Fanart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="97"/>
        <source>Search Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="98"/>
        <source>Select Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="99"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="100"/>
        <source>Starring:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="101"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="105"/>
        <source>Systems:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="106"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="112"/>
        <source>_</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="113"/>
        <source>genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="114"/>
        <source>system:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="33"/>
        <source>Cover Art:</source>
        <translation>Omslagsbild:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="63"/>
        <source>Game is a Favorite</source>
        <translation>Spelet är en favorit</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="25"/>
        <source>Click here to search existing coverart...</source>
        <translation>Klicka här för att söka bland tillgängliga omslagsbilder...</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="27"/>
        <source>Click here to search existing screenshots...</source>
        <translation>Klicka här för att söka bland tillgängliga skärmbilder...</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="26"/>
        <source>Click here to search existing fanart...</source>
        <translation>Klicka här för att söka bland tillgängliga användarbilder...</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="41"/>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="79"/>
        <source>Play Games</source>
        <translation>Spela spel</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="84"/>
        <source>ROM Path:</source>
        <oldsource>ROM Name:</oldsource>
        <translation type="unfinished">ROM-namn:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="84"/>
        <source>ROM Path:</source>
        <translation>ROM-sökväg:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="65"/>
        <source>Game:</source>
        <translation>Spel:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="108"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="52"/>
        <source>Filename:</source>
        <translation>Filnamn:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="102"/>
        <source>System(s):</source>
        <translation>System:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="20"/>
        <source>CRC:</source>
        <translation>CRC:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="38"/>
        <source>Description:</source>
        <translation>Beskrivning:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="76"/>
        <source>No Plot.</source>
        <translation>Ingen handling.</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="44"/>
        <source>Empty your game library</source>
        <translation>Töm ditt spelbibliotek</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="78"/>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="55"/>
        <source>Game Information</source>
        <translation>Spelinformation</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="75"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="107"/>
        <source>Type</source>
        <translation type="unfinished">Typ</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="110"/>
        <source>Year: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="themestrings.h" line="111"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="66"/>
        <source>Games</source>
        <translation>Spel</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="53"/>
        <source>From %1</source>
        <translation>Från %1</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="104"/>
        <source>System: %1</source>
        <translation>System: %1</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="69"/>
        <source>Genre: %1</source>
        <translation>Genre: %1</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="17"/>
        <source>Back</source>
        <translation>Tillbaka</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="86"/>
        <source>ROM path:</source>
        <translation>ROM-sökväg:</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="48"/>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="67"/>
        <source>General Settings</source>
        <translation>Generella inställningar</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="61"/>
        <source>Game folders and general options</source>
        <translation>Spelkataloger och generella inställningar</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="57"/>
        <source>Game Players</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="28"/>
        <source>Configure an emulator</source>
        <translation>Konfigurera en emulator</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="91"/>
        <source>Scan for Games</source>
        <translation>Sök efter spel</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="15"/>
        <source>Add games to your library</source>
        <translation>Lägg till spel till ditt spelbibliotek</translation>
    </message>
    <message>
        <location filename="themestrings.h" line="22"/>
        <source>Clear Game Data</source>
        <translation>Rensa speldata</translation>
    </message>
</context>
</TS>
